@@ -525,3 +525,28 @@ func TestSplittingPublicPathEntryName(t *testing.T) {
 		},
 	})
 }
+
+func TestSplittingChunkPathDirPlaceholderImplicitOutbase(t *testing.T) {
+	splitting_suite.expectBundled(t, bundled{
+		files: map[string]string{
+			"/project/entry.js": `
+				console.log(import('./output-path/should-contain/this-text/file'))
+			`,
+			"/project/output-path/should-contain/this-text/file.js": `
+				console.log('file.js')
+			`,
+		},
+		entryPaths: []string{"/project/entry.js"},
+		options: config.Options{
+			Mode:          config.ModeBundle,
+			OutputFormat:  config.FormatESModule,
+			CodeSplitting: true,
+			AbsOutputDir:  "/out",
+			ChunkPathTemplate: []config.PathTemplate{
+				{Data: "./", Placeholder: config.DirPlaceholder},
+				{Data: "/", Placeholder: config.NamePlaceholder},
+				{Data: "-", Placeholder: config.HashPlaceholder},
+			},
+		},
+	})
+}
