@@ -1,6 +1,6 @@
 package compat
 
-type CSSFeature uint32
+type CSSFeature uint8
 
 const (
 	HexRGBA CSSFeature = 1 << iota
@@ -18,10 +18,30 @@ const (
 	Nesting
 )
 
+var StringToCSSFeature = map[string]CSSFeature{
+	"hex-rgba":       HexRGBA,
+	"rebecca-purple": RebeccaPurple,
+	"modern-rgb-hsl": Modern_RGB_HSL,
+	"inset-property": InsetProperty,
+	"nesting":        Nesting,
+}
+
+var CSSFeatureToString = map[CSSFeature]string{
+	HexRGBA:        "hex-rgba",
+	RebeccaPurple:  "rebecca-purple",
+	Modern_RGB_HSL: "modern-rgb-hsl",
+	InsetProperty:  "inset-property",
+	Nesting:        "nesting",
+}
+
 func (features CSSFeature) Has(feature CSSFeature) bool {
 	return (features & feature) != 0
 }
 
+func (features CSSFeature) ApplyOverrides(overrides CSSFeature, mask CSSFeature) CSSFeature {
+	return (features & ^mask) | (overrides & mask)
+}
+
 var cssTable = map[CSSFeature]map[Engine][]versionRange{
 	// Data from: https://developer.mozilla.org/en-US/docs/Web/CSS/color_value
 	HexRGBA: {
