@@ -5,9 +5,9 @@ import (
 	"strings"
 	"sync"
 
+	"github.com/evanw/esbuild/internal/ast"
 	"github.com/evanw/esbuild/internal/helpers"
 	"github.com/evanw/esbuild/internal/js_ast"
-	"github.com/evanw/esbuild/internal/logger"
 )
 
 var processedGlobalsMutex sync.Mutex
@@ -842,16 +842,26 @@ var knownGlobals = [][]string{
 	{"window"},
 }
 
-type DefineArgs struct {
-	FindSymbol      func(logger.Loc, string) js_ast.Ref
-	SymbolForDefine func(int) js_ast.Ref
-	Loc             logger.Loc
+// We currently only support compile-time replacement with certain expressions:
+//
+//   - Primitive literals
+//   - Identifiers
+//   - "Entity names" which are identifiers followed by property accesses
+//
+// We don't support arbitrary expressions because arbitrary expressions may
+// require the full AST. For example, there could be "import()" or "require()"
+// expressions that need an import record. We also need to re-generate some
+// nodes such as identifiers within the injected context so that they can
+// bind to symbols in that context. Other expressions such as "this" may
+// also be contextual.
+type DefineExpr struct {
+	Constant            js_ast.E
+	Parts               []string
+	InjectedDefineIndex ast.Index32
 }
 
-type DefineFunc func(DefineArgs) js_ast.E
-
 type DefineData struct {
-	DefineFunc DefineFunc
+	DefineExpr *DefineExpr
 
 	// True if accessing this value is known to not have any side effects. For
 	// example, a bare reference to "Object.create" can be removed because it
@@ -928,13 +938,13 @@ func ProcessDefines(userDefines map[string]DefineData) ProcessedDefines {
 
 	// Swap in certain literal values because those can be constant folded
 	result.IdentifierDefines["undefined"] = DefineData{
-		DefineFunc: func(DefineArgs) js_ast.E { return js_ast.EUndefinedShared },
+		DefineExpr: &DefineExpr{Constant: js_ast.EUndefinedShared},
 	}
 	result.IdentifierDefines["NaN"] = DefineData{
-		DefineFunc: func(DefineArgs) js_ast.E { return &js_ast.ENumber{Value: math.NaN()} },
+		DefineExpr: &DefineExpr{Constant: &js_ast.ENumber{Value: math.NaN()}},
 	}
 	result.IdentifierDefines["Infinity"] = DefineData{
-		DefineFunc: func(DefineArgs) js_ast.E { return &js_ast.ENumber{Value: math.Inf(1)} },
+		DefineExpr: &DefineExpr{Constant: &js_ast.ENumber{Value: math.Inf(1)}},
 	}
 
 	// Then copy the user-specified defines in afterwards, which will overwrite
