@@ -19,7 +19,7 @@ func expectPrintedCommon(t *testing.T, name string, contents string, expected st
 	t.Helper()
 	t.Run(name, func(t *testing.T) {
 		t.Helper()
-		log := logger.NewDeferLog(logger.DeferLogNoVerboseOrDebug)
+		log := logger.NewDeferLog(logger.DeferLogNoVerboseOrDebug, nil)
 		tree := css_parser.Parse(log, test.SourceForTest(contents), css_parser.Options{
 			MinifyWhitespace: options.MinifyWhitespace,
 		})
