@@ -130,18 +130,17 @@ func (p *parser) skipTypeScriptFnArgs() {
 // This is a spot where the TypeScript grammar is highly ambiguous. Here are
 // some cases that are valid:
 //
-//     let x = (y: any): (() => {}) => { };
-//     let x = (y: any): () => {} => { };
-//     let x = (y: any): (y) => {} => { };
-//     let x = (y: any): (y[]) => {};
-//     let x = (y: any): (a | b) => {};
+//	let x = (y: any): (() => {}) => { };
+//	let x = (y: any): () => {} => { };
+//	let x = (y: any): (y) => {} => { };
+//	let x = (y: any): (y[]) => {};
+//	let x = (y: any): (a | b) => {};
 //
 // Here are some cases that aren't valid:
 //
-//     let x = (y: any): (y) => {};
-//     let x = (y: any): (y) => {return 0};
-//     let x = (y: any): asserts y is (y) => {};
-//
+//	let x = (y: any): (y) => {};
+//	let x = (y: any): (y) => {return 0};
+//	let x = (y: any): asserts y is (y) => {};
 func (p *parser) skipTypeScriptParenOrFnType() {
 	if p.trySkipTypeScriptArrowArgsWithBacktracking() {
 		p.skipTypeScriptReturnType()
@@ -175,6 +174,7 @@ const (
 	tsTypeIdentifierAsserts
 	tsTypeIdentifierPrefix
 	tsTypeIdentifierPrimitive
+	tsTypeIdentifierInfer
 )
 
 // Use a map to improve lookup speed
@@ -185,7 +185,6 @@ var tsTypeIdentifierMap = map[string]tsTypeIdentifierKind{
 
 	"keyof":    tsTypeIdentifierPrefix,
 	"readonly": tsTypeIdentifierPrefix,
-	"infer":    tsTypeIdentifierPrefix,
 
 	"any":       tsTypeIdentifierPrimitive,
 	"never":     tsTypeIdentifierPrimitive,
@@ -197,9 +196,12 @@ var tsTypeIdentifierMap = map[string]tsTypeIdentifierKind{
 	"boolean":   tsTypeIdentifierPrimitive,
 	"bigint":    tsTypeIdentifierPrimitive,
 	"symbol":    tsTypeIdentifierPrimitive,
+
+	"infer": tsTypeIdentifierInfer,
 }
 
 func (p *parser) skipTypeScriptTypeWithOpts(level js_ast.L, opts skipTypeOpts) {
+loop:
 	for {
 		switch p.lexer.Token {
 		case js_lexer.TNumericLiteral, js_lexer.TBigIntegerLiteral, js_lexer.TStringLiteral,
@@ -291,8 +293,10 @@ func (p *parser) skipTypeScriptTypeWithOpts(level js_ast.L, opts skipTypeOpts) {
 
 		case js_lexer.TIdentifier:
 			kind := tsTypeIdentifierMap[p.lexer.Identifier.String]
+			checkTypeParameters := true
 
-			if kind == tsTypeIdentifierPrefix {
+			switch kind {
+			case tsTypeIdentifierPrefix:
 				p.lexer.Next()
 
 				// Valid:
@@ -305,27 +309,40 @@ func (p *parser) skipTypeScriptTypeWithOpts(level js_ast.L, opts skipTypeOpts) {
 				if p.lexer.Token != js_lexer.TColon || (!opts.isIndexSignature && !opts.allowTupleLabels) {
 					p.skipTypeScriptType(js_ast.LPrefix)
 				}
-				break
-			}
+				break loop
 
-			checkTypeParameters := true
+			case tsTypeIdentifierInfer:
+				p.lexer.Next()
 
-			if kind == tsTypeIdentifierUnique {
+				// "type Foo = Bar extends [infer T] ? T : null"
+				// "type Foo = Bar extends [infer T extends string] ? T : null"
+				if p.lexer.Token != js_lexer.TColon || (!opts.isIndexSignature && !opts.allowTupleLabels) {
+					p.lexer.Expect(js_lexer.TIdentifier)
+					if p.lexer.Token == js_lexer.TExtends {
+						p.lexer.Next()
+						p.skipTypeScriptType(js_ast.LPrefix)
+					}
+				}
+				break loop
+
+			case tsTypeIdentifierUnique:
 				p.lexer.Next()
 
 				// "let foo: unique symbol"
 				if p.lexer.IsContextualKeyword("symbol") {
 					p.lexer.Next()
-					break
+					break loop
 				}
-			} else if kind == tsTypeIdentifierAbstract {
+
+			case tsTypeIdentifierAbstract:
 				p.lexer.Next()
 
 				// "let foo: abstract new () => {}" added in TypeScript 4.2
 				if p.lexer.Token == js_lexer.TNew {
 					continue
 				}
-			} else if kind == tsTypeIdentifierAsserts {
+
+			case tsTypeIdentifierAsserts:
 				p.lexer.Next()
 
 				// "function assert(x: boolean): asserts x"
@@ -333,10 +350,12 @@ func (p *parser) skipTypeScriptTypeWithOpts(level js_ast.L, opts skipTypeOpts) {
 				if opts.isReturnType && !p.lexer.HasNewlineBefore && (p.lexer.Token == js_lexer.TIdentifier || p.lexer.Token == js_lexer.TThis) {
 					p.lexer.Next()
 				}
-			} else if kind == tsTypeIdentifierPrimitive {
+
+			case tsTypeIdentifierPrimitive:
 				p.lexer.Next()
 				checkTypeParameters = false
-			} else {
+
+			default:
 				p.lexer.Next()
 			}
 
@@ -843,7 +862,7 @@ func (p *parser) isTSArrowFnJSX() (isTSArrowFn bool) {
 	// Look ahead to see if this should be an arrow function instead
 	if p.lexer.Token == js_lexer.TIdentifier {
 		p.lexer.Next()
-		if p.lexer.Token == js_lexer.TComma {
+		if p.lexer.Token == js_lexer.TComma || p.lexer.Token == js_lexer.TEquals {
 			isTSArrowFn = true
 		} else if p.lexer.Token == js_lexer.TExtends {
 			p.lexer.Next()
@@ -988,16 +1007,44 @@ func (p *parser) skipTypeScriptInterfaceStmt(opts parseStmtOpts) {
 }
 
 func (p *parser) skipTypeScriptTypeStmt(opts parseStmtOpts) {
-	if opts.isExport && p.lexer.Token == js_lexer.TOpenBrace {
-		// "export type {foo}"
-		// "export type {foo} from 'bar'"
-		p.parseExportClause()
-		if p.lexer.IsContextualKeyword("from") {
+	if opts.isExport {
+		switch p.lexer.Token {
+		case js_lexer.TOpenBrace:
+			// "export type {foo}"
+			// "export type {foo} from 'bar'"
+			p.parseExportClause()
+			if p.lexer.IsContextualKeyword("from") {
+				p.lexer.Next()
+				p.parsePath()
+			}
+			p.lexer.ExpectOrInsertSemicolon()
+			return
+
+		// This is invalid TypeScript, and is rejected by the TypeScript compiler:
+		//
+		//   example.ts:1:1 - error TS1383: Only named exports may use 'export type'.
+		//
+		//   1 export type * from './types'
+		//     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+		//
+		// However, people may not know this and then blame esbuild for it not
+		// working. So we parse it anyway and then discard it (since we always
+		// discard all types). People who do this should be running the TypeScript
+		// type checker when using TypeScript, which will then report this error.
+		case js_lexer.TAsterisk:
+			// "export type * from 'path'"
 			p.lexer.Next()
+			if p.lexer.IsContextualKeyword("as") {
+				// "export type * as ns from 'path'"
+				p.lexer.Next()
+				p.parseClauseAlias("export")
+				p.lexer.Next()
+			}
+			p.lexer.ExpectContextualKeyword("from")
 			p.parsePath()
+			p.lexer.ExpectOrInsertSemicolon()
+			return
 		}
-		p.lexer.ExpectOrInsertSemicolon()
-		return
 	}
 
 	name := p.lexer.Identifier.String
@@ -1268,9 +1315,10 @@ func (p *parser) parseTypeScriptImportEqualsStmt(loc logger.Loc, opts parseStmtO
 		for p.lexer.Token == js_lexer.TDot {
 			p.lexer.Next()
 			value.Data = &js_ast.EDot{
-				Target:  value,
-				Name:    p.lexer.Identifier.String,
-				NameLoc: p.lexer.Loc(),
+				Target:               value,
+				Name:                 p.lexer.Identifier.String,
+				NameLoc:              p.lexer.Loc(),
+				CanBeRemovedIfUnused: true,
 			}
 			p.lexer.Expect(js_lexer.TIdentifier)
 		}
