@@ -52,6 +52,7 @@ let initializeWasCalled = false
 export const initialize: typeof types.initialize = async (options) => {
   options = common.validateInitializeOptions(options || {})
   if (options.wasmURL) throw new Error(`The "wasmURL" option only works in the browser`)
+  if (options.wasmModule) throw new Error(`The "wasmModule" option only works in the browser`)
   if (options.worker) throw new Error(`The "worker" option only works in the browser`)
   if (initializeWasCalled) throw new Error('Cannot call "initialize" more than once')
   await ensureServiceIsRunning()
@@ -145,10 +146,14 @@ async function install(): Promise<string> {
     'x86_64-pc-windows-msvc': 'esbuild-windows-64',
   }
   const knownUnixlikePackages: Record<string, string> = {
+    // These are the only platforms that Deno supports
     'aarch64-apple-darwin': 'esbuild-darwin-arm64',
     'aarch64-unknown-linux-gnu': 'esbuild-linux-arm64',
     'x86_64-apple-darwin': 'esbuild-darwin-64',
     'x86_64-unknown-linux-gnu': 'esbuild-linux-64',
+
+    // These platforms are not supported by Deno
+    'x86_64-unknown-freebsd': 'esbuild-freebsd-64',
   }
 
   // Pick a package to install
@@ -218,7 +223,7 @@ let ensureServiceIsRunning = (): Promise<Service> => {
           startWriteFromQueueWorker()
         },
         isSync: false,
-        isBrowser: false,
+        isWriteUnavailable: false,
         esbuild: ourselves,
       })
 
@@ -293,7 +298,7 @@ let ensureServiceIsRunning = (): Promise<Service> => {
                 },
                 writeFile(contents, callback) {
                   Deno.makeTempFile().then(
-                    tempFile => Deno.writeFile(tempFile, new TextEncoder().encode(contents)).then(
+                    tempFile => Deno.writeFile(tempFile, typeof contents === 'string' ? new TextEncoder().encode(contents) : contents).then(
                       () => callback(tempFile),
                       () => callback(null)),
                     () => callback(null))
