@@ -110,7 +110,7 @@ const startRunningService = async (wasmURL: string, wasmModule: WebAssembly.Modu
       worker.postMessage(bytes)
     },
     isSync: false,
-    isBrowser: true,
+    isWriteUnavailable: true,
     esbuild: ourselves,
   })
 
