@@ -2,11 +2,16 @@ import fs = require('fs');
 import os = require('os');
 import path = require('path');
 
+declare const ESBUILD_VERSION: string;
+
 // This feature was added to give external code a way to modify the binary
 // path without modifying the code itself. Do not remove this because
 // external code relies on this.
 export var ESBUILD_BINARY_PATH: string | undefined = process.env.ESBUILD_BINARY_PATH || ESBUILD_BINARY_PATH;
 
+const packageDarwin_arm64 = 'esbuild-darwin-arm64'
+const packageDarwin_x64 = 'esbuild-darwin-64'
+
 export const knownWindowsPackages: Record<string, string> = {
   'win32 arm64 LE': 'esbuild-windows-arm64',
   'win32 ia32 LE': 'esbuild-windows-32',
@@ -34,6 +39,7 @@ export const knownUnixlikePackages: Record<string, string> = {
 };
 
 export const knownWebAssemblyFallbackPackages: Record<string, string> = {
+  'android arm LE': '@esbuild/android-arm',
   'android x64 LE': 'esbuild-android-64',
 };
 
@@ -129,11 +135,7 @@ export function generateBinPath(): { binPath: string, isWASM: boolean } {
         // helpful in that case.
         const otherPkg = pkgForSomeOtherPlatform();
         if (otherPkg) {
-          throw new Error(`
-You installed esbuild on another platform than the one you're currently using.
-This won't work because esbuild is written with native code and needs to
-install a platform-specific binary executable.
-
+          let suggestions = `
 Specifically the "${otherPkg}" package is present but this platform
 needs the "${pkg}" package instead. People often get into this
 situation by installing esbuild on Windows or macOS and copying "node_modules"
@@ -143,14 +145,46 @@ Windows and WSL environments.
 If you are installing with npm, you can try not copying the "node_modules"
 directory when you copy the files over, and running "npm ci" or "npm install"
 on the destination platform after the copy. Or you could consider using yarn
-instead which has built-in support for installing a package on multiple
+instead of npm which has built-in support for installing a package on multiple
 platforms simultaneously.
 
 If you are installing with yarn, you can try listing both this platform and the
 other platform in your ".yarnrc.yml" file using the "supportedArchitectures"
 feature: https://yarnpkg.com/configuration/yarnrc/#supportedArchitectures
 Keep in mind that this means multiple copies of esbuild will be present.
+`
 
+          // Use a custom message for macOS-specific architecture issues
+          if (
+            (pkg === packageDarwin_x64 && otherPkg === packageDarwin_arm64) ||
+            (pkg === packageDarwin_arm64 && otherPkg === packageDarwin_x64)
+          ) {
+            suggestions = `
+Specifically the "${otherPkg}" package is present but this platform
+needs the "${pkg}" package instead. People often get into this
+situation by installing esbuild with npm running inside of Rosetta 2 and then
+trying to use it with node running outside of Rosetta 2, or vice versa (Rosetta
+2 is Apple's on-the-fly x86_64-to-arm64 translation service).
+
+If you are installing with npm, you can try ensuring that both npm and node are
+not running under Rosetta 2 and then reinstalling esbuild. This likely involves
+changing how you installed npm and/or node. For example, installing node with
+the universal installer here should work: https://nodejs.org/en/download/. Or
+you could consider using yarn instead of npm which has built-in support for
+installing a package on multiple platforms simultaneously.
+
+If you are installing with yarn, you can try listing both "arm64" and "x64"
+in your ".yarnrc.yml" file using the "supportedArchitectures" feature:
+https://yarnpkg.com/configuration/yarnrc/#supportedArchitectures
+Keep in mind that this means multiple copies of esbuild will be present.
+`
+          }
+
+          throw new Error(`
+You installed esbuild for another platform than the one you're currently using.
+This won't work because esbuild is written with native code and needs to
+install a platform-specific binary executable.
+${suggestions}
 Another alternative is to use the "esbuild-wasm" package instead, which works
 the same way on all platforms. But it comes with a heavy performance cost and
 can sometimes be 10x slower than the "esbuild" package, so you may also not
@@ -168,8 +202,9 @@ want to do that.
         throw new Error(`The package "${pkg}" could not be found, and is needed by esbuild.
 
 If you are installing esbuild with npm, make sure that you don't specify the
-"--no-optional" flag. The "optionalDependencies" package.json feature is used
-by esbuild to install the correct binary executable for your current platform.`);
+"--no-optional" or "--omit=optional" flags. The "optionalDependencies" feature
+of "package.json" is used by esbuild to install the correct binary executable
+for your current platform.`);
       }
       throw e;
     }
@@ -179,16 +214,40 @@ by esbuild to install the correct binary executable for your current platform.`)
   // it's inside a virtual file system and the OS needs it in the real file
   // system. So we need to copy the file out of the virtual file system into
   // the real file system.
-  let isYarnPnP = false;
+  //
+  // You might think that we could use "preferUnplugged: true" in each of the
+  // platform-specific packages for this instead, since that tells Yarn to not
+  // use the virtual file system for those packages. This is not done because:
+  //
+  // * Really early versions of Yarn don't support "preferUnplugged", so package
+  //   installation would break on those Yarn versions if we did this.
+  //
+  // * Earlier Yarn versions always installed all optional dependencies for all
+  //   platforms even though most of them are incompatible. To minimize file
+  //   system space, we want these useless packages to take up as little space
+  //   as possible so they should remain unzipped inside their ".zip" files.
+  //
+  //   We have to explicitly pass "preferUnplugged: false" instead of leaving
+  //   it up to Yarn's default behavior because Yarn's heuristics otherwise
+  //   automatically unzip packages containing ".exe" files, and we don't want
+  //   our Windows-specific packages to be unzipped either.
+  //
+  let pnpapi: any;
   try {
-    require('pnpapi');
-    isYarnPnP = true;
+    pnpapi = require('pnpapi');
   } catch (e) {
   }
-  if (isYarnPnP) {
-    const esbuildLibDir = path.dirname(require.resolve('esbuild'));
-    const binTargetPath = path.join(esbuildLibDir, `pnpapi-${pkg}-${path.basename(subpath)}`);
+  if (pnpapi) {
+    const root = pnpapi.getPackageInformation(pnpapi.topLevel).packageLocation;
+    const binTargetPath = path.join(
+      root,
+      'node_modules',
+      '.cache',
+      'esbuild',
+      `pnpapi-${pkg}-${ESBUILD_VERSION}-${path.basename(subpath)}`,
+    );
     if (!fs.existsSync(binTargetPath)) {
+      fs.mkdirSync(path.dirname(binTargetPath), { recursive: true });
       fs.copyFileSync(binPath, binTargetPath);
       fs.chmodSync(binTargetPath, 0o755);
     }
